// Use this as a stub if you don't need deminimization, and are not including third.js
mw$.compiled = true;
